pub struct RasterMultiMergeParams {
pub opacity: f64,
pub blend_mode: i64,
}Expand description
Composites a variadic stack of raster layers in order.
Fields
opacity: f64Opacity applied to each layer as it is composited.
blend_mode: i64Blend mode used for each layer in the stack.