Module switch

Module switch 

Structs

Switch
Selects one raster input according to a controlled layer index.
SwitchParams
Selects one raster input according to a controlled layer index.
SwitchParamsDelegate

Functions

selected_layer_for_frame