pub struct Memo {
pub id: NodeId,
pub cache_id: NodeProperty,
pub allow_expressions: NodeProperty,
pub source: PortRef,
}Expand description
Aliases a raster input through a stable cache boundary.
Fields
id: NodeIdcache_id: NodePropertyStable cache identifier for this memo boundary.
allow_expressions: NodePropertyAllows property expressions to be evaluated across this memo boundary.
source: PortRefTrait Implementations
Sourceimpl GpuCompileNode for Memo
impl GpuCompileNode for Memo
fn compile_gpu( &self, ctx: &mut CompileContext<'_>, port: &PortRef, ) -> Result<CompiledOutput, LumenError>
Sourceimpl GpuFrameBindNode for Memo
impl GpuFrameBindNode for Memo
fn bind_gpu_frame( &self, ctx: &FrameBindContext<'_>, binding: &FrameBinding, _bound: &mut BoundFrame, ) -> Result<(), LumenError>
Sourceimpl Node for Memo
impl Node for Memo
fn id(&self) -> NodeId
fn input_port_defs(&self) -> &'static [InputPortDef]
fn output_port_defs(&self) -> &'static [OutputPortDef]
Sourceimpl PropertyEval for Memo
impl PropertyEval for Memo
fn get_property(&self, id: &str) -> Result<Option<NodeProperty>, LumenError>