pub struct MemoParams {
pub cache_id: String,
pub allow_expressions: bool,
}Expand description
Aliases a raster input through a stable cache boundary.
Fields
cache_id: StringStable cache identifier for this memo boundary.
allow_expressions: boolAllows property expressions to be evaluated across this memo boundary.