Module media_in
lumen_
engine
0.2.2
Module media_
in
Module Items
Structs
Enums
Functions
In lumen_
engine::
node::
source
lumen_engine
::
node
::
source
Module
media_
in
Structs

MediaIn
Binds an external image or video frame as a GPU texture.
Media
InParams
Binds an external image or video frame as a GPU texture.
Media
InParams
Delegate
Enums

Loop
Mode
Media
InKind
Functions

map_
to_
source_
frame
resolve_
for_
context
resolve_
range