Module switch
lumen_
engine
0.2.1
Module switch
Module Items
Structs
Functions
In lumen_
engine::
node::
compositing
lumen_engine
::
node
::
compositing
Module
switch
Structs

Switch
Selects one raster input according to a controlled layer index.
Switch
Params
Selects one raster input according to a controlled layer index.
Switch
Params
Delegate
Functions

selected_
layer_
for_
frame